<?php
// $Id: google_docs.theme.inc,v 1.1 2010/10/06 14:08:33 flexer Exp $

/**
 * @file
 * The google_docs module, theme functions.
 */

function theme_google_docs_doclist($documents, $page=FALSE) {

  if ($page) {
    drupal_add_css(drupal_get_path('module', 'google_docs') .'/google_docs.css');
  }
  
  $ipath = drupal_get_path('module', 'google_docs') . "/icons";
  $items = array();

  if ($page) {
    $logo = theme('image', "{$ipath}/gdocs_text_16.png", t('Google Docs logo'), t('Google Docs logo'), array('class' => 'gdocs-text'));
    $text = t('These documents are hosted on <a href="@gurl">!logo</a> and are not present on this site. Documents authors are therefore not actual users of this site. To edit, view or download any of these documents, you need <strong>your Google account</strong> to be given access to them by one of the document editor.', array('!logo' => $logo, '@gurl' => "http://docs.google.com"));
    $output =<<< EOHTML
      <div class="gdocs-heading">
      <a href="http://docs.google.com"><img class='icon' src='/{$ipath}/gdocs_64.png' /></a>{$text}
      </div>
EOHTML;
  }
  
  if (!$documents) {
    $output .= "<p>" . t('No document present.') . "</p>";
  }
  else {
  
    $icosize = ($page ? '32' : '16');
    
    $up_txt = ($page ? t('Updated on') : '');
    $by_txt = t('by');
    $h = ($page ? "h2" : "h3");
    
    foreach ($documents as $doc) {
      $date = format_date($doc['updated'], 'small');
      $edit = l(t('View / Edit'), $doc['links']['edit']); 
      $kind = $doc['categories']['kind'];
      
      $download = '';
      if ($page && ($formats = google_docs_get_export_formats($kind))) {
        $base = ($kind == 'spreadsheet' ? GOOGLE_DOCS_SPREADSHEET_EXPORT_URI : GOOGLE_DOCS_DOCUMENT_EXPORT_URI);
        $idkey = ($kind == 'spreadsheet' ? 'key' : 'docId');
        $download = '&ndash; ' . t('Download');
        foreach ($formats as $format) {
          $download .= ' ' . l($format, str_replace('%s', $kind, $base), array('attributes' => array('class' => 'gdocs-download', 'target' => '_blank'), 'query' => "{$idkey}=" . urlencode($doc['id']) . "&exportFormat={$format}"));
        }
      }
      
      $items[] = "<{$h} class='title'><img title='{$kind}' alt='{$kind}' class='gdocs-icon' src=\"/{$ipath}/gdoc_{$kind}_{$icosize}.png\"/> {$doc['title']}</{$h}>" . "<p class='metadata'>{$up_txt} {$date} {$by_txt} <strong>{$doc['updatedBy']}</strong> &ndash; {$edit} {$download}</p>";
    }
    
    $output .= theme('item_list', $items, NULL, 'ul', array('class' => 'gdocs-list'));
    
    if (!$page) {
      $ctx = _google_docs_get_context();
      $output .= "<div class=\"more-link\">" . l(t('Show all'), "google_docs/{$ctx->nid}/doclist") . "</div>";
    }
  }
  
  return $output;
}
